/**
*	WARNING: Do Not Remove This Section
*
*	$RCSfile: simulation_utils_01.c,v $
*	$Revision: 1.5 $
*	$Date: 2007/12/07 14:25:05 $
*	$Author: d.jansen $
*	
*	MRMC is a model checker for discrete-time and continuous-time Markov
*	reward models. It supports reward extensions of PCTL and CSL (PRCTL 
*	and CSRL), and allows for the automated verification of properties
*	concerning long-run and instantaneous rewards as well as cumulative
*	rewards.
*	
* 	Copyright (C) The University of Twente, 2004-2008.
* 	Copyright (C) RWTH Aachen, 2008-2009.
*	Authors: Ivan Zapreev
*
*	This program is free software; you can redistribute it and/or
*	modify it under the terms of the GNU General Public License
*	as published by the Free Software Foundation; either version 2
*	of the License, or (at your option) any later version.
*
*	This program is distributed in the hope that it will be useful,
*	but WITHOUT ANY WARRANTY; without even the implied warranty of
*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*	GNU General Public License for more details.
*
*	You should have received a copy of the GNU General Public License
*	along with this program; if not, write to the Free Software
*	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*	Main contact:
*		Lehrstuhl für Informatik 2, RWTH Aachen University
*		Ahornstrasse 55, 52074 Aachen, Germany
*		E-mail: info@mrmc-tool.org
*	
*	Old ontact:
*		Formal Methods and Tools Group, University of Twente,
*		P.O. Box 217, 7500 AE Enschede, The Netherlands,
*		Phone: +31 53 4893767, Fax: +31 53 4893247,
*		E-mail: mrmc@cs.utwente.nl
*
*	Source description: This is for testing the simulation utils only.
*	Uses: Definition of simulation utils - simulation_utils.h
*/

#include "macro.h"
#include "simulation_utils.h"
#include "parser_to_tree.h"

/*
NOTE: THE TESTS IN THIS FILE SHOULD NOT FAIL. IF ONE OF THE
TESTS FAILS - SOMETHING'S REALLY WRONG.

IN CONTRAST TO THE TESTS HERE IN PRACTICE SOME INVOCATIONS
CAN FAIL DUE TO SPURIOUS INPUTS PROVIDED THAT THE TESTS HERE
WERE SUCCESSFUL. CONSEQUENTLY IT IS NECESSARY TO CHECK FOR
SPURIOUS INPUTS IN PRACTICAL SCENARIOS.
*/

static void test_conf_int_vs_prob_constraint(const int comparator, const double prob_bound,
					const double leftCondIntB, const double rightCondIntB,
					const double indiff_width){
	TV_LOGIC tvl_result = checkBoundVSConfInt( comparator, prob_bound, leftCondIntB, rightCondIntB, indiff_width );
	printf(" [%e, %e] ", leftCondIntB, rightCondIntB);
	switch(comparator){
		case COMPARATOR_SF_LESS :
			printf("<");
			break;
		case COMPARATOR_SF_LESS_OR_EQUAL :
			printf("<=");
			break;
		case COMPARATOR_SF_GREATER :
			printf(">");
			break;
		case COMPARATOR_SF_GREATER_OR_EQUAL :
			printf(">=");
			break;
		default:
			printf("??");
	}
	printf(" %e == ", prob_bound );
	switch( tvl_result ){
		case TVL_NN:
			printf("NN");
			break;
		case TVL_FF:
			printf("FF");
			break;
		case TVL_TT:
			printf("TT");
			break;
		default:
			printf("??");
	}
	printf("\n");
}

int main(){
	const double leftCondIntB = 0.4;
	const double rightCondIntB = 0.6;
	const double indiff_good = rightCondIntB - leftCondIntB + 0.01;
	const double indiff_bad = rightCondIntB - leftCondIntB - 0.01;
	const double middle_pr_b = ( leftCondIntB + rightCondIntB ) / 2.0;
	const double left_pr_b = leftCondIntB/2.0;
	const double right_pr_b = rightCondIntB + (1.0 - rightCondIntB)/2.0;
	
	printf("\n************ < p **********\n");
	
	printf("*A negative test for the bad conf.int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, 0.1 , leftCondIntB, rightCondIntB, indiff_bad );

	printf("*A test for the prob bound inside the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, middle_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, leftCondIntB, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, rightCondIntB, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound < left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, left_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound > right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS, right_pr_b, leftCondIntB , rightCondIntB, indiff_good );
	
	printf("\n************ <= p **********\n");

	printf("*A negative test for the bad conf.int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, 0.4 , leftCondIntB, rightCondIntB, indiff_bad );

	printf("*A test for the prob bound inside the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, middle_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, leftCondIntB, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, rightCondIntB, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound < left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, left_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound > right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_LESS_OR_EQUAL, right_pr_b, leftCondIntB , rightCondIntB, indiff_good );
	
	printf("\n************ > p **********\n");

	printf("*A negative test for the bad conf.int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, 0.6 , leftCondIntB, rightCondIntB, indiff_bad );

	printf("*A test for the prob bound inside the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, middle_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, leftCondIntB, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound == right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, rightCondIntB, rightCondIntB, rightCondIntB, indiff_good );

	printf("*A test for the prob bound < left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, left_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound > right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER, right_pr_b, leftCondIntB , rightCondIntB, indiff_good );
	
	printf("\n************ >= p **********\n");

	printf("*A negative test for the bad conf.int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, 0.9 , leftCondIntB, rightCondIntB, indiff_bad );

	printf("*A test for the prob bound inside the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, middle_pr_b, leftCondIntB, rightCondIntB, indiff_good );

	printf("*A test for the prob bound == left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, leftCondIntB, leftCondIntB, rightCondIntB, indiff_good );

	printf("*A test for the prob bound == right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, rightCondIntB, leftCondIntB, rightCondIntB, indiff_good );

	printf("*A test for the prob bound < left border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, left_pr_b, leftCondIntB , rightCondIntB, indiff_good );

	printf("*A test for the prob bound > right border of the conf. int.:\n");
	test_conf_int_vs_prob_constraint( COMPARATOR_SF_GREATER_OR_EQUAL, right_pr_b, leftCondIntB , rightCondIntB, indiff_good );
	
	return 0;
}
