/**
*	WARNING: Do Not Remove This Section
*
*	$RCSfile: simulation_utils_02.c,v $
*	$Revision: 1.6 $
*	$Date: 2007/11/29 11:06:29 $
*	$Author: i.zapreev $
*	
*	MRMC is a model checker for discrete-time and continuous-time Markov
*	reward models. It supports reward extensions of PCTL and CSL (PRCTL 
*	and CSRL), and allows for the automated verification of properties
*	concerning long-run and instantaneous rewards as well as cumulative
*	rewards.
*	
* 	Copyright (C) The University of Twente, 2004-2008.
* 	Copyright (C) RWTH Aachen, 2008-2009.
*	Authors: Ivan Zapreev
*
*	This program is free software; you can redistribute it and/or
*	modify it under the terms of the GNU General Public License
*	as published by the Free Software Foundation; either version 2
*	of the License, or (at your option) any later version.
*
*	This program is distributed in the hope that it will be useful,
*	but WITHOUT ANY WARRANTY; without even the implied warranty of
*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*	GNU General Public License for more details.
*
*	You should have received a copy of the GNU General Public License
*	along with this program; if not, write to the Free Software
*	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*
*	Main contact:
*		Lehrstuhl für Informatik 2, RWTH Aachen University
*		Ahornstrasse 55, 52074 Aachen, Germany
*		E-mail: info@mrmc-tool.org
*	
*	Old ontact:
*		Formal Methods and Tools Group, University of Twente,
*		P.O. Box 217, 7500 AE Enschede, The Netherlands,
*		Phone: +31 53 4893767, Fax: +31 53 4893247,
*		E-mail: mrmc@cs.utwente.nl
*
*	Source description: This is for testing the simulation utils only.
*	Uses: Definition of simulation utils - simulation_utils.h
*/

#include "macro.h"
#include "simulation_utils.h"
#include "sample_vec.h"

/*
NOTE: THE TESTS IN THIS FILE SHOULD NOT FAIL. IF ONE OF THE
TESTS FAILS - SOMETHING'S REALLY WRONG.

IN CONTRAST TO THE TESTS HERE IN PRACTICE SOME INVOCATIONS
CAN FAIL DUE TO SPURIOUS INPUTS PROVIDED THAT THE TESTS HERE
WERE SUCCESSFUL. CONSEQUENTLY IT IS NECESSARY TO CHECK FOR
SPURIOUS INPUTS IN PRACTICAL SCENARIOS.
*/

int main(){
	/*STANDARD CONF. INT.*/
	
	/*For the confidence 0.974679*/
	const double conf_zeta = 1.96;
	const int sample_size_one = 10, sample_size_two = 20;
	double ciLeftBorder, ciRightBorder;
	int Sg, Sgt;
	
	PTSampleVecUntil pSampleVecUntil = allocateSampleVectorUntil( sample_size_one, 1 );
	
	/*One set of values*/
	Sg = (pSampleVecUntil->sum_good = 6);
	Sgt = ( pSampleVecUntil->sum_trans = 1 ) + Sg;
	
	/*ciLeftBorder = 6/10-1.96/Sqrt(10)*Sqrt(6*(10-6)/(10*(10-1))) = 0.27993334*/
	/*ciRightBorder = 7/10+1.96/Sqrt(10)*Sqrt(7*(10-7)/(10*(10-1))) = 0.999394945*/
	computeBordersUU( conf_zeta, &ciLeftBorder, &ciRightBorder, pSampleVecUntil, STANDARD_CONF_INT );
	printf("The conf. int. for sample_size = %d, conf_zeta = %e, Sg = %d and Sgt = %d is [%e, %e].\n",
		sample_size_one, conf_zeta, Sg, Sgt, ciLeftBorder, ciRightBorder);
	
	/*Another set of values*/
	Sg = (pSampleVecUntil->sum_good = 5);
	Sgt = ( pSampleVecUntil->sum_trans = 1 ) + Sg;
	/*ciLeftBorder = (5-1.96*Sqrt(5*(10-5)/(10-1)))/10 = 0.173333333*/
	/*ciRightBorder = (6+1.96*Sqrt(6*(10-6)/(10-1)))/10 = 0.92006666*/
	computeBordersUU( conf_zeta, &ciLeftBorder, &ciRightBorder, pSampleVecUntil, STANDARD_CONF_INT );
	printf("The conf. int. for sample_size = %d, conf_zeta = %e, Sg = %d and Sgt = %d is [%e, %e].\n",
		sample_size_one, conf_zeta, Sg, Sgt, ciLeftBorder, ciRightBorder);
	
	freeSampleVectorUntil( pSampleVecUntil );
	
	pSampleVecUntil = allocateSampleVectorUntil( sample_size_two, 1 );
	
	/*One set of values*/
	Sg = (pSampleVecUntil->sum_good = 6);
	Sgt = ( pSampleVecUntil->sum_trans = 6 ) + Sg;
	/*ciLeftBorder = (6-1.96*Sqrt(6*(20-6)/(20-1)))/20 = 0.093942267*/
	/*ciRightBorder = (12+1.96*Sqrt(12*(20-12)/(20-1)))/20 = 0.820284983*/
	computeBordersUU( conf_zeta, &ciLeftBorder, &ciRightBorder, pSampleVecUntil, STANDARD_CONF_INT );
	printf("The conf. int. for sample_size = %d, conf_zeta = %e, Sg = %d and Sgt = %d is [%e, %e].\n",
		sample_size_two, conf_zeta, Sg, Sgt, ciLeftBorder, ciRightBorder);
	
	/*Another set of values*/
	Sg = (pSampleVecUntil->sum_good = 7);
	Sgt = ( pSampleVecUntil->sum_trans = 5 ) + Sg;
	/*ciLeftBorder = (7-1.96*Sqrt(7*(20-7)/(20-1)))/20 = 0.135528311*/
	/*ciRightBorder = (12+1.96*Sqrt(12*(20-12)/(20-1)))/20 = 0.820284983*/
	computeBordersUU( conf_zeta, &ciLeftBorder, &ciRightBorder, pSampleVecUntil, STANDARD_CONF_INT );
	printf("The conf. int. for sample_size = %d, conf_zeta = %e, Sg = %d and Sgt = %d is [%e, %e].\n",
		sample_size_two, conf_zeta, Sg, Sgt, ciLeftBorder, ciRightBorder);
	
	freeSampleVectorUntil( pSampleVecUntil );
	
	return 0;
}
