#!/bin/bash -u

#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: clean.sh,v $
#	$Revision: 1.5 $
#	$Date: 2008/06/11 06:36:51 $
#	$Author: i.zapreev $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	Source description: This script does cleaning, i.e removes *.out, *.diff, and etc.
#

#%%%%%%%%%%%%SET UP SOME IMPORTANT PATHS%%%%%%%%%%%%%%%
PWD=`eval pwd`
LOCAL_PWD=${PWD}
PERFORMANCE_GCC_SCRIPTS=${PWD}/scripts/gcc
STAT_DIR_NAME=statistics

#
# This function recursively traverses the folders, using the test_list
# files and on every level it cleans the tmp files
# @param ${1} the folder we descended to
#
doRecursiveCleaning () {
	#Allows to trace the progress
	echo -n "${1}/"	
	
	#Perform some unconditional cleaning (should be done everywhere)
	rm -f *~
	
	#Go down if there is a test_list file here, i.e. we are on a test-suite level
	if test -f "test_list"; then
		#Go through the test-suite tests or sub-suites
		TEST_SUITES=`eval cat test_list | sed -e '/#.*/d'`
		for test_suite in ${TEST_SUITES}; do
			#Move in
			cd ${test_suite}
			#Call recursive cleaning
			doRecursiveCleaning ${test_suite}
			#Move out
			cd ..
		done
	else
		#If there is no test_list then we are in the test directory
		#Remove the model and simple test output related files
		rm -f *~ *.out *.diff *.tra *.lab  *.output *.tmp *.rew *.rewi *.java *.class *.log
		#Remove common statistics and temporary files
		rm -f *.results *.statistics *.memstat *.memstat.old *.memstat.new
		#Remove intermediate statistics of the simulation tests
		rm -rf ${STAT_DIR_NAME}
	fi
	
	#Erase the "${1}/" string from the output
	NAME_LENGTH=${#1}
	BSP_STRING=""
        BLANK_STRING=""
	let "NUMBER_OF_BSP = ${NAME_LENGTH} + 1"
	for (( i=1 ; i <= ${NUMBER_OF_BSP} ; i++ )) ; do
		BSP_STRING="${BSP_STRING}\b"
		BLANK_STRING="${BLANK_STRING} "
	done
	echo -n -e "${BSP_STRING}${BLANK_STRING}${BSP_STRING}"
}

#%%%%%%%%%%%%%%%%%%CLEAN PROGRAMMS%%%%%%%%%%%%%%%%%%%%%
cd ${PERFORMANCE_GCC_SCRIPTS}
make -e clean
cd ${LOCAL_PWD}

#%%%%%%%%%%%%%%%%%%%%CLEAN TESTS%%%%%%%%%%%%%%%%%%%%%%%
echo -n "Cleaning: "
doRecursiveCleaning "."
echo "DONE"

