#!/bin/bash -u

#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: compare_out_golden_prob.sh,v $
#	$Revision: 1.7 $
#	$Date: 2007/12/01 17:39:08 $
#	$Author: i.zapreev $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2007.
#	Authors: Christina Jansen, Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	Source description: This script compares Results vector regarding a given error bound
#

#	@param ${1} the test_list file
#	@param ${2} the error bound e.g. 1.0e-6


#Define sed pattern
#Erase text and brackets
RESULT_RULE="s/\$RESULT://;s/( //;s/ )//"
#every number in a new line
NEWLINE_RULE="s/, /\n/g"

#Define script path
export TEST_PATH=performance_tests
export LUMPING_AWK_SCRIPTS=`eval echo ${PWD} | sed -e 's/performance_tests.*$//'`${TEST_PATH}/lumping/scripts/awk
echo "Using Script: ${LUMPING_AWK_SCRIPTS}"

if [ $# -ne 2 ];
then
	echo "ERROR: parameter undefined"
	echo "Usage: compare_out_golden_prob.sh test_list error_bound"
	echo "Info:  This script compares the *.out to *.golden files."
	echo "       It is aimed at comparing the probability values."
	echo "       The difference between corresponding probabilities"
	echo "       is checked not to exceed 2*error_bound."
else
	TESTS=`eval cat ${1} | sed -e '/#.*/d'` ; export TESTS
	for test in ${TESTS}
	do
		echo "Processing the test: ${test}"
		cd ${test}
	
		#Unzip all goldens in test case	
		unzip -u ${test}.zip
		
		#Unzip all goldens in the directory
		OUT_FILES=`eval ls *.out | sed -e "s/${test}.prism.log.out//"`
		for out in ${OUT_FILES}; do
			TEST_CASE_NAME=`echo ${out} | sed -e 's/.out//'`
			echo "  Processing the test case: ${TEST_CASE_NAME}"
				#Delete everything except from the numbers of the result vector
				grep RESULT ${TEST_CASE_NAME}.out | sed -e "${RESULT_RULE}" -e "${NEWLINE_RULE}" > ${TEST_CASE_NAME}_r.tmp.out
				grep RESULT ${TEST_CASE_NAME}.golden | sed -e "${RESULT_RULE}" -e "${NEWLINE_RULE}" > ${TEST_CASE_NAME}_r.tmp.golden
				
				#Call script for comparing the results of .out and .golden file
				awk -v error_bound="${2}" -f ${LUMPING_AWK_SCRIPTS}/compare_out_golden_prob.awk ${TEST_CASE_NAME}_r.tmp.out ${TEST_CASE_NAME}_r.tmp.golden

				#Delete temporary files
				rm -f ${TEST_CASE_NAME}_r.tmp.out
				rm -f ${TEST_CASE_NAME}_r.tmp.golden
				rm -f ${TEST_CASE_NAME}.golden
			echo "  DONE"
		done
		cd ..
	
	done
fi
