#!/bin/bash -u

#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: statistics.sh,v $
#	$Revision: 1.14 $
#	$Date: 2007/12/12 13:23:08 $
#	$Author: i.zapreev $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	Source description: This script collects and processes the statistical data.
#	@param ${1} the test_list  file
#	@param ${2} the input_list  file
#	@param ${3} the PERFORMANCE or MEMORY option for ${PERFORMANCE} or ${MEMORY} statistics
#

PERFORMANCE="performance"
MEMORY="memory"

TESTS=`eval cat ${1} | sed -e '/#.*/d'`

INPUTS=`eval cat ${2} | sed -e '/#.*/d'`

#Set up the data units
if test "${3}" == "${PERFORMANCE}"; then
	STAT_TYPE=${PERFORMANCE}
	DATA_UNIT=${MILLISECONDS}
	STAT_FILES_EXT="${STAT_TYPE}.statistics"
	GNUPLOT_FILES_EXT="${STAT_TYPE}.gnuplot"
elif test "${3}" == "${MEMORY}"; then
	STAT_TYPE=${MEMORY}
	DATA_UNIT=${KILOBYTES}
	STAT_FILES_EXT="${STAT_TYPE}.statistics"
	GNUPLOT_FILES_EXT="${STAT_TYPE}.gnuplot"
else
	echo "ERROR: Unknown type of statistics, check the .test/performance_tests/lumping/scripts/shell/test_suite.sh script."
	exit 1
fi

####################################################
#%%%%%%%%%%%%EXECUTE DATA PROCESSING%%%%%%%%%%%%%%%#
####################################################

export PATH=.:${PATH}		#Add local directory to the path, otherwise the tests will not run

#remove previous statistics
rm -f *.${STAT_FILES_EXT}

#Perform data collection and processing for the statistics.
echo "------------ Collecting statistics and preparing data ------------"
for test in ${TESTS}
do
	cd ${test}
	TEST_NAME=${test}
	echo "${TEST_NAME}: "
	for input in ${INPUTS}
	do
		echo "  ${input}:"
		#WARNING: The options_line is needed for the performance statistics scripts
		options_line=1	#Initialize the line counter
		cat ../option_list | sed -e '/#.*/d' | while read options; do
			#Used for constructing the test case name
			OPTS=`eval echo ${options} | sed -e 's/ /./'`
			TEST_CASE_NAME=${TEST_NAME}.${OPTS}.${input}
			
			echo -n "    ${TEST_CASE_NAME}"
			
			#Collect statistics
			source ${LUMPING_SHELL_SCRIPTS}/${STAT_TYPE}_generate_statistics.sh
			
			let "options_line+=1"	#Increment the line counter
			
			echo " ..........DONE"
		done
	done
	cd ..
done

echo "Converting the statistics into the gnuplot data files:"
for input in ${INPUTS}
do
	#Prepare the input parameters for the awk script
	OUT_DAT_FILE_NAME=${input}.${STAT_TYPE}
	OUT_DAT_FILE=${OUT_DAT_FILE_NAME}.dat;
	PARAM=${TEST_SUBSUITE_NAME}.param;

	echo "  ${OUT_DAT_FILE}: "
	
	#Remove the old dat file
	rm -f ${OUT_DAT_FILE}.dat;
	
	#Place the input files into the arrange_table.awk input
	#in the same order as we have options in the optins_list
	#such that the columns are ordered by the MRMC options
	rm -f stat.files.tmp
	cat option_list | sed -e '/#.*/d' | while read options; do
		OPTS=`eval echo ${options} | sed -e 's/ /./'`
		
		#Generate list of statistic files
		source ${LUMPING_SHELL_SCRIPTS}/${STAT_TYPE}_generate_stat_files_list.sh
		
	done
	STAT_FILES_LIST=`eval cat stat.files.tmp`
	rm -f stat.files.tmp
	
	#Arrange the dat file with all gnuplot data
	echo "${PARAM} ${STAT_FILES_LIST}" | awk -v out_file_name=${OUT_DAT_FILE} -v normalization_factor=${DATA_UNIT} -f ${PERFORMANCE_AWK_SCRIPTS}/arrange_table.awk
	
	#Get rid of "," which whould be substituted by "."
	#Because awk and gnuplot have different format for real numbers
	cat ${OUT_DAT_FILE} | sed -e 's/,/./g' > ${OUT_DAT_FILE}.tmp
	rm -f ${OUT_DAT_FILE}
	mv ${OUT_DAT_FILE}.tmp ${OUT_DAT_FILE}
	
	#Source the script that defines the data-unit name for the statistics, i.e. DATA_UNIT_STR
	. ${PERFORMANCE_SHELL_SCRIPTS}/${STAT_TYPE}_define_data_unit.sh
	
	#Source the script that produces the MIN/MAX data range in the form of exported variables: MIN MAX
	. ${PERFORMANCE_SHELL_SCRIPTS}/min_max_data_range.sh
	
	#Generate gnuplot ot of the template and then make eps files.
	${PERFORMANCE_SHELL_SCRIPTS}/generate_eps.sh  "${input}.${GNUPLOT_FILES_EXT}" "${MIN}" "${MAX}" "${OUT_DAT_FILE_NAME}" "${OUT_DAT_FILE_NAME}" "${DATA_UNIT_STR}"
	
	echo "    --==WE ARE DONE==--"
done
