#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: average.awk,v $
#	$Revision: 1.6 $
#	$Date: 2007/12/11 16:24:02 $
#	$Author: i.zapreev $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	Source description: This program just reads the column of elements
# 	from the file and computes their average. 
#	@param mult:	 ( -v mult=?). It gives the possibility to compute
#			 the average for -ilump option of MRMC when time
#			 used for lumping is computed separately.
#			 In other words for example for -ilump option of MRMC
#			 time for lumping is computed separately. Thus we have
#			 two times for each run so the multiple should be 2
#	@param out_file: ( -v mult="?") stores the output file name
#			this is required to iutput the given tests
#			statistics into the correct output file in
#			order to collect it for plotting.
#	
#	WARNING: In case the average is zero it is set to 0.001 and then
#		   is multiplied by the 'mult'. This is because the script is used to
#		   compute average runtime of MRMC which is now in milliseconds and thus
#		   can be zero!
#

BEGIN {
	#print "Computing the average time, given multiple is " mult;
	if ( mult == 0 ) {
		print "\nERROR: The value of parameter mult is 0!"
		exit 1;
	}
	if ( out_file == "" ) {
		print "\nERROR: The value of parameter out_file is undefined!"
		exit 1;
	}
	total = 0;
}

{
	i +=1; #Count the total numner of rows
	
	#WARNING: A potential round off problem!
	total =  total * ( i - 1 ) / i + $1 / i ; #Compute average
}

END {
	if ( i != 0 && out_file != "" ) {
		if( total == 0){
			#In case we've got zero milliseconds let's set it
			#to 1 microsecond since otherwise we will have a
			#problem with log scale in gnuplot script
			total = 0.001;
		}
		print (total * mult) >> out_file;
	}else{
		print "\nERROR: the out_file is not set!"
	}
}
