#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: confidence_stat_importance.awk,v $
#	$Revision: 1.1 $
#	$Date: 2006/12/15 15:23:53 $
#	$Author: zapreevis $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#
#	This program computes the confidence interval for the mean
#	difference of values in the input file.
#	The input file should look like:
#
#	val11 val12
#	val21 val22
#	...........
#
#	The number of entries - experiments should be assigned to the N variable here
#	The T_P_Nm1 is the Student's T-distribution table value for
#	t_{ 1-\frac{ \alpha }{2}, N - 1} for the desired confidence probability 1 - \alpha
#
#	NOTE: If the MEAN value is negative it means that the FIRST COLUMN values in the input file are
#	on average greater than the values on the SECOND COLUMN. The statistical significance of this
#	fact is supported if the computed confidence interval does not contain ZERO.
#	The same for the positive MEAN VALUE.

BEGIN{
	#The expected number of experiments
	N = 66;
	#The Student's t-distribution value for P=0.95, Nm1 = N -1 = 65
	T_P_Nm1 = 1.669; #Set to the T_0.095_65, the confidence then is 90%

	#The actual counter for the number of experiments
	COUNT = 0;
}

{
	#Compute and store the difference between 1 and 2 column elements
	difference[COUNT] = $1 - $2;
	#Increase the counter
	COUNT = COUNT + 1;
}

END {
	#Check for the right number of experiments
	if( COUNT != N ) {
		print "ERROR: The expected number of experiments is ", N, ", we have gotten ", COUNT, "!";
		exit 1;
	}
	
	#Compute sample mean
	TOTAL = 0;
	for ( x = 0; x < N; x ++){
		TOTAL = TOTAL + difference[x];
	}
	MEAN = TOTAL / N;
	print "The sample MEAN value for the difference is: ", MEAN, ".";

	#Compute sample deviation
	TOTAL = 0;
	for ( x = 0; x < N; x ++){
		TOTAL = TOTAL + ( difference[x] - MEAN )^2;
	}
	DEVIATION = sqrt( TOTAL / (N - 1) );
	print "The sample DEVIATION value for the difference is: ", DEVIATION, ".";

	#Compute the confidence interval
	BOUND = T_P_Nm1 * ( DEVIATION / sqrt( N ) );
	C1 = MEAN - BOUND;
	C2 = MEAN + BOUND;
	print "The confidence interval is: [" ,C1 , "," ,C2 , "].";

}
