#
#	WARNING: Do Not Remove This Section
#
#	$RCSfile: min_max.awk,v $
#	$Revision: 1.9 $
#	$Date: 2008/06/10 10:49:21 $
#	$Author: i.zapreev $
#	
#	MRMC is a model checker for discrete-time and continuous-time Markov reward models.
#	It supports reward extensions of PCTL and CSL (PRCTL and CSRL), and allows for the
#	automated verification of properties concerning long-run and instantaneous rewards
#	as well as cumulative rewards.
#	
#	Copyright (C) The University of Twente, 2004-2006.
#	Authors: Ivan Zapreev
#
#	This program is free software; you can redistribute it and/or
#	modify it under the terms of the GNU General Public License
#	as published by the Free Software Foundation; either version 2
#	of the License, or (at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program; if not, write to the Free Software
#	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#	Our contacts:
#		Formal Methods and Tools Group, University of Twente,
#		P.O. Box 217, 7500 AE Enschede, The Netherlands,
#		Phone: +31 53 4893767, Fax: +31 53 4893247,
#		E-mail: mrmc@cs.utwente.nl
#	
#	Source description: Here we compute the minimum and maximum values for the
#	plot ranges which are then later used in gnuplot. 
#	The input is the list of files which we have to read
#	and just find the MIN and MAX values! Prints
#		"MIN/normalization_factor;MAX/normalization_factor"
#	in the output.
#
#	NOTE: There is a -v normalization_factor="..." parameter that should be a number
#	it is used to normilize the resulting output of the script
#
#	--Example 01: For performance analysis MRMC produces elapsed-time
#	output time in milliseconds, sometimes we want to have results in
#	seconds, then we should use:
#		-v normalization_factor=1000,
#	For minutes:
#		-v normalization_factor=60000,
#	etc ...
#	
#	--Example 02: For the pick memory usage 'ps' produces results in Kb
#	sometimes we want to have results in Mb, then we should use:
#		-v normalization_factor=1024.
#	For Gb:
#		-v normalization_factor=1048576,
#	etc ...

BEGIN{
	RS="\n| ";
	first = 1;
}

{
	while ( ( getline line < $0 ) > 0){
		if ( first == 1 ){
			MAX = line;
			MIN = line;
			first = 0;
		}else{
			if ( line + 1 > MAX + 1 ) {
				MAX = line;
			}else{
				if ( line + 1 < MIN + 1 ) {
					MIN = line;
				}
			}
		}
	}
	close($0)
}

END {
	OFS=";"
	
	#In case something goes wrong we would like not to have empty MIN/MAX interal
	if( MIN == 0 ){
		MIN = 0.001;
	}
	if( MAX == 0 ){
		MAX = 0.002;
	}
	#If the values are the same, then we increase the maximum value by 1%
	if( MIN == MAX){
		MAX = MAX + MAX / 100;
	}
	
	#NOTE: Here we convert the vales in to the desired data unit
	#NOTE: David N. Jansen modified the next line with the comment:
	# This makes the graphs appear with 10% extra space below the minimum  
	# and 10% above the maximum. I like graphs where the curves do not  
	# touch the lower or upper border more. Because the y-axis is  
	# "typically" logarithmic, I did the following calculation:
	# exp( log(MIN) - 0.1 * (log(MAX)-log(MIN)) ) = MIN^1.1 / MAX^0.1 
	print MIN^1.1 / MAX^0.1 / normalization_factor, MAX^1.1 / MIN^0.1 / normalization_factor;
}
